// All user related API calls

import { useAuthorizationCache } from '../store';

export type User = {
  Name: string;
  Email: string;
  SignInProvider: number;
};

export const useUserAPI = () => {
  const { accessToken } = useAuthorizationCache();
  const domain = import.meta.env.VITE_BACKEND_URL;

  function GetUserInfo(): Promise<User> {
    return new Promise<User>((resolve, reject) => {
      fetch(`${domain}/user/`, {
        method: 'GET',
        credentials: 'same-origin',
        headers: new Headers({
          Authorization: 'Bearer ' + accessToken,
        }),
      })
        .then((response: Response) => {
          if (!response.ok) {
            reject(response.statusText);
          }

          return response.json();
        })
        .then((json: any) => {
          resolve({
            Name: json.name,
            Email: json.email,
            SignInProvider: json.sign_in_provider,
          });
        });
    });
  }

  return { GetUserInfo };
};
