import React from 'react';
import { Meta } from '@storybook/react';
import { NodeLinkVis } from './nodelinkvis';

import { assignNewGraphQueryResult, graphQueryResultSlice, resetGraphQueryResults, store } from '../../data-access/store';
import { configureStore } from '@reduxjs/toolkit';
import { Provider } from 'react-redux';
import { big2ndChamberQueryResult, smallFlightsQueryResults, mockLargeQueryResults } from '../../mock-data';

const Component: Meta<typeof NodeLinkVis> = {
  /* 👇 The title prop is optional.
   * See https://storybook.js.org/docs/react/configure/overview#configure-story-loading
   * to learn how to generate automatic titles
   */
  title: 'Components/Visualizations/NodeLinkVis',
  component: NodeLinkVis,
  decorators: [
    (story) => (
      <Provider store={Mockstore}>
        <div
          style={{
            width: '100%',
            height: '100vh',
          }}
        >
          {story()}
        </div>
      </Provider>
    ),
  ],
};

const Mockstore = configureStore({
  reducer: {
    graphQueryResult: graphQueryResultSlice.reducer,
  },
});

export const TestWithData = {
  args: {
    loading: false,
  },
  play: async () => {
    const dispatch = Mockstore.dispatch;
    dispatch(
      assignNewGraphQueryResult({
        type: 'nodelink',
        payload: {
          nodes: [
            { id: 'agent/007', attributes: { name: 'Daniel Craig' } },
            { id: 'villain', attributes: { name: 'Le Chiffre' } },
          ],
          edges: [{ id: 'escape/escape', from: 'agent/007', to: 'villain', attributes: { name: 'Escape' } }],
        },
      })
    );
  },
};

export const TestWithNoData = {
  args: { loading: false },
  play: async () => {
    const dispatch = Mockstore.dispatch;
    dispatch(
      assignNewGraphQueryResult({
        type: 'nodelink',
        payload: {
          nodes: [],
          edges: [],
        },
      })
    );
  },
};

export const TestWithBig2ndChamber = {
  args: { loading: false },
  play: async () => {
    const dispatch = Mockstore.dispatch;
    dispatch(assignNewGraphQueryResult({ type: 'nodelink', payload: big2ndChamberQueryResult }));
  },
};

export const TestWithSmallFlights = {
  args: { loading: false },
  play: async () => {
    const dispatch = Mockstore.dispatch;
    dispatch(assignNewGraphQueryResult({ type: 'nodelink', payload: smallFlightsQueryResults }));
  },
};

export const TestWithLargeQueryResult = {
  args: { loading: false },
  play: async () => {
    const dispatch = Mockstore.dispatch;
    dispatch(assignNewGraphQueryResult({ type: 'nodelink', payload: mockLargeQueryResults }));
  },
};

// export const Loading = Template.bind({});
// Loading.args = {
//   loading: true,
// };
//
// export const Empty = Template.bind({});
// Empty.args = {
//   // Shaping the stories through args composition.
//   // Inherited data coming from the Loading story.
//   ...Loading.args,
//   loading: false,
// };
// Empty.play = async () => {
//   const dispatch = store.dispatch;
//   dispatch(resetGraphQueryResults());
// };

export default Component;
